@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 Derick Rethans                               |
+   | Copyright (c) 1997-2019 Derick Rethans                               |
    +----------------------------------------------------------------------+
    | This source file is subject to the 2-Clause BSD license which is     |
    | available through the LICENSE file, or online at                     |
@@ -23,53 +23,28 @@
 #include "srm_oparray.h"
 #include "php_globals.h"
 
-#if PHP_VERSION_ID >= 50300
-# define APPLY_TSRMLS_CC TSRMLS_CC
-# define APPLY_TSRMLS_DC TSRMLS_DC
-#else
-# define APPLY_TSRMLS_CC
-# define APPLY_TSRMLS_DC
-#endif
-
 static zend_op_array* (*old_compile_file)(zend_file_handle* file_handle, int type TSRMLS_DC);
 static zend_op_array* vld_compile_file(zend_file_handle*, int TSRMLS_DC);
 
 static zend_op_array* (*old_compile_string)(zval *source_string, char *filename TSRMLS_DC);
 static zend_op_array* vld_compile_string(zval *source_string, char *filename TSRMLS_DC);
 
-#if PHP_VERSION_ID >= 50500
 static void (*old_execute_ex)(zend_execute_data *execute_data TSRMLS_DC);
 static void vld_execute_ex(zend_execute_data *execute_data TSRMLS_DC);
-#else
-static void (*old_execute)(zend_op_array *op_array TSRMLS_DC);
-static void vld_execute(zend_op_array *op_array TSRMLS_DC);
-#endif
 
 /* {{{ forward declarations */
 static int vld_check_fe (zend_op_array *fe, zend_bool *have_fe TSRMLS_DC);
-static int vld_dump_fe (zend_op_array *fe APPLY_TSRMLS_DC, int num_args, va_list args, zend_hash_key *hash_key);
-#if defined(ZEND_ENGINE_3)
+static int vld_dump_fe (zend_op_array *fe TSRMLS_DC, int num_args, va_list args, zend_hash_key *hash_key);
 static int vld_dump_cle (zend_class_entry *class_entry TSRMLS_DC);
-#elif defined(ZEND_ENGINE_2)
-static int vld_dump_cle (zend_class_entry **class_entry TSRMLS_DC);
-#else
-static int vld_dump_cle (zend_class_entry *class_entry TSRMLS_DC);
-#endif
 /* }}} */
 
-#if PHP_VERSION_ID < 50300
-# define ZEND_FE_END { NULL, NULL, NULL }
-#endif
-
 zend_function_entry vld_functions[] = {
 	ZEND_FE_END
 };
 
 
 zend_module_entry vld_module_entry = {
-#if ZEND_MODULE_API_NO >= 20010901
 	STANDARD_MODULE_HEADER,
-#endif
 	"vld",
 	vld_functions,
 	PHP_MINIT(vld),
@@ -77,9 +52,7 @@ zend_module_entry vld_module_entry = {
 	PHP_RINIT(vld),	
 	PHP_RSHUTDOWN(vld),
 	PHP_MINFO(vld),
-#if ZEND_MODULE_API_NO >= 20010901
-	"0.15.0",
-#endif
+	"0.16.0",
 	STANDARD_MODULE_PROPERTIES
 };
 
@@ -110,7 +83,7 @@ static void vld_init_globals(zend_vld_globals *vg)
 	vg->skip_append  = 0;
 	vg->execute      = 1;
 	vg->format       = 0;
-	vg->col_sep	  = "\t";
+	vg->col_sep      = (char*) "\t";
 	vg->path_dump_file = NULL;
 	vg->dump_paths   = 1;
 	vg->save_paths   = 0;
@@ -132,14 +105,8 @@ PHP_MSHUTDOWN_FUNCTION(vld)
 	UNREGISTER_INI_ENTRIES();
 
 	zend_compile_file   = old_compile_file;
-#if (PHP_MAJOR_VERSION > 5) || (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 2)
 	zend_compile_string = old_compile_string;
-#endif
-#if PHP_VERSION_ID >= 50500
 	zend_execute_ex     = old_execute_ex;
-#else
-	zend_execute        = old_execute;
-#endif
 
 	return SUCCESS;
 }
@@ -149,26 +116,14 @@ PHP_MSHUTDOWN_FUNCTION(vld)
 PHP_RINIT_FUNCTION(vld)
 {
 	old_compile_file = zend_compile_file;
-#if (PHP_MAJOR_VERSION > 5) || (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 2)
 	old_compile_string = zend_compile_string;
-#endif
-#if PHP_VERSION_ID >= 50500
 	old_execute_ex = zend_execute_ex;
-#else
-	old_execute = zend_execute;
-#endif
 
 	if (VLD_G(active)) {
 		zend_compile_file = vld_compile_file;
-#if (PHP_MAJOR_VERSION > 5) || (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 2)
 		zend_compile_string = vld_compile_string;
-#endif
 		if (!VLD_G(execute)) {
-#if PHP_VERSION_ID >= 50500
 			zend_execute_ex = vld_execute_ex;
-#else
-			zend_execute = vld_execute;
-#endif
 		}
 	}
 
@@ -192,15 +147,9 @@ PHP_RINIT_FUNCTION(vld)
 
 PHP_RSHUTDOWN_FUNCTION(vld)
 {
-	zend_compile_file = old_compile_file;
-#if (PHP_MAJOR_VERSION > 5) || (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 2)
+	zend_compile_file   = old_compile_file;
 	zend_compile_string = old_compile_string;
-#endif
-#if PHP_VERSION_ID >= 50500
-	zend_execute_ex   = old_execute_ex;
-#else
-	zend_execute      = old_execute;
-#endif
+	zend_execute_ex     = old_execute_ex;
 
 	if (VLD_G(path_dump_file)) {
 		fprintf(VLD_G(path_dump_file), "}\n");
@@ -222,8 +171,6 @@ PHP_MINFO_FUNCTION(vld)
 }
 
 /* {{{ PHP 7 wrappers */
-#if defined(ZEND_ENGINE_3)
-
 #define VLD_WRAP_PHP7(name) name ## _wrapper
 
 static int vld_check_fe_wrapper (zval *el, zend_bool *have_fe TSRMLS_DC)
@@ -231,20 +178,15 @@ static int vld_check_fe_wrapper (zval *el, zend_bool *have_fe TSRMLS_DC)
 	return vld_check_fe((zend_op_array *) Z_PTR_P(el), have_fe TSRMLS_CC);
 }
 
-static int vld_dump_fe_wrapper(zval *el APPLY_TSRMLS_DC, int num_args, va_list args, zend_hash_key *hash_key)
+static int vld_dump_fe_wrapper(zval *el TSRMLS_DC, int num_args, va_list args, zend_hash_key *hash_key)
 {
-	return vld_dump_fe((zend_op_array *) Z_PTR_P(el) APPLY_TSRMLS_CC, num_args, args, hash_key);
+	return vld_dump_fe((zend_op_array *) Z_PTR_P(el) TSRMLS_CC, num_args, args, hash_key);
 }
 
 static int vld_dump_cle_wrapper (zval *el TSRMLS_DC)
 {
 	return vld_dump_cle((zend_class_entry *) Z_PTR_P(el) TSRMLS_CC);
 }
-#else
-
-#define VLD_WRAP_PHP7(name) name
-
-#endif
 /* }}} */
 
 int vld_printf(FILE *stream, const char* fmt, ...)
@@ -290,16 +232,10 @@ static int vld_check_fe (zend_op_array *fe, zend_bool *have_fe TSRMLS_DC)
 	return 0;
 }
 
-static int vld_dump_fe (zend_op_array *fe APPLY_TSRMLS_DC, int num_args, va_list args, zend_hash_key *hash_key)
+static int vld_dump_fe (zend_op_array *fe TSRMLS_DC, int num_args, va_list args, zend_hash_key *hash_key)
 {
-#if PHP_VERSION_ID < 50300
-	TSRMLS_FETCH()
-#endif
 	if (fe->type == ZEND_USER_FUNCTION) {
 		ZVAL_VALUE_STRING_TYPE *new_str;
-#if PHP_VERSION_ID < 70000
-		int new_len;
-#endif
 
 		new_str = php_url_encode(ZHASHKEYSTR(hash_key), ZHASHKEYLEN(hash_key) PHP_URLENCODE_NEW_LEN(new_len));
 		vld_printf(stderr, "Function %s:\n", ZSTRING_VALUE(new_str));
@@ -312,20 +248,11 @@ static int vld_dump_fe (zend_op_array *fe APPLY_TSRMLS_DC, int num_args, va_list
 }
 
 
-#if defined(ZEND_ENGINE_2)
-static int vld_dump_cle (zend_class_entry **class_entry TSRMLS_DC)
-#else
 static int vld_dump_cle (zend_class_entry *class_entry TSRMLS_DC)
-#endif
 {
 	zend_class_entry *ce;
 	zend_bool have_fe = 0;
-
-#if defined(ZEND_ENGINE_2)
-	ce = *class_entry;
-#else
 	ce = class_entry;
-#endif
 
 	if (ce->type != ZEND_INTERNAL_CLASS) {	
 		if (VLD_G(path_dump_file)) {
@@ -336,7 +263,7 @@ static int vld_dump_cle (zend_class_entry *class_entry TSRMLS_DC)
 
 		if (have_fe) {
 			vld_printf(stderr, "Class %s:\n", ZSTRING_VALUE(ce->name));
-			zend_hash_apply_with_arguments(&ce->function_table APPLY_TSRMLS_CC, (apply_func_args_t) VLD_WRAP_PHP7(vld_dump_fe), 0);
+			zend_hash_apply_with_arguments(&ce->function_table TSRMLS_CC, (apply_func_args_t) VLD_WRAP_PHP7(vld_dump_fe), 0);
 			vld_printf(stderr, "End of class %s.\n\n", ZSTRING_VALUE(ce->name));
 		} else {
 			vld_printf(stderr, "Class %s: [no user functions]\n", ZSTRING_VALUE(ce->name));
@@ -362,16 +289,12 @@ static zend_op_array *vld_compile_file(zend_file_handle *file_handle, int type T
 	     (VLD_G(skip_append)  && PG(auto_append_file)  && PG(auto_append_file)[0]  && PG(auto_append_file)  == file_handle->filename)))
 	{
 		zval nop;
-#if PHP_VERSION_ID >= 70000
+
 		zend_op_array *ret;
 		ZVAL_STRINGL(&nop, "RETURN ;", 8);
-		ret = compile_string(&nop, "NOP" TSRMLS_CC);
+		ret = compile_string(&nop, (char*) "NOP" TSRMLS_CC);
 		zval_dtor(&nop);
 		return ret;
-#else
-		ZVAL_STRINGL(&nop, "RETURN ;", 8, 0);
-		return compile_string(&nop, "NOP" TSRMLS_CC);
-#endif
 	}
 
 	op_array = old_compile_file (file_handle, type TSRMLS_CC);
@@ -383,7 +306,7 @@ static zend_op_array *vld_compile_file(zend_file_handle *file_handle, int type T
 		vld_dump_oparray (op_array TSRMLS_CC);
 	}
 
-	zend_hash_apply_with_arguments (CG(function_table) APPLY_TSRMLS_CC, (apply_func_args_t) VLD_WRAP_PHP7(vld_dump_fe), 0);
+	zend_hash_apply_with_arguments (CG(function_table) TSRMLS_CC, (apply_func_args_t) VLD_WRAP_PHP7(vld_dump_fe), 0);
 	zend_hash_apply (CG(class_table), (apply_func_t) VLD_WRAP_PHP7(vld_dump_cle) TSRMLS_CC);
 
 	if (VLD_G(path_dump_file)) {
@@ -405,13 +328,8 @@ static zend_op_array *vld_compile_string(zval *source_string, char *filename TSR
 	if (op_array) {
 		vld_dump_oparray (op_array TSRMLS_CC);
 
-#if defined(ZEND_ENGINE_3)
-		zend_hash_apply_with_arguments (CG(function_table) APPLY_TSRMLS_CC, (apply_func_args_t) vld_dump_fe_wrapper, 0);
+		zend_hash_apply_with_arguments (CG(function_table) TSRMLS_CC, (apply_func_args_t) vld_dump_fe_wrapper, 0);
 		zend_hash_apply (CG(class_table), (apply_func_t) vld_dump_cle_wrapper TSRMLS_CC);
-#else
-		zend_hash_apply_with_arguments (CG(function_table) APPLY_TSRMLS_CC, (apply_func_args_t) vld_dump_fe, 0);
-		zend_hash_apply (CG(class_table), (apply_func_t) vld_dump_cle TSRMLS_CC);
-#endif
 	}
 
 	return op_array;
@@ -419,16 +337,8 @@ static zend_op_array *vld_compile_string(zval *source_string, char *filename TSR
 /* }}} */
 
 /* {{{
- *    PHP >= 5.5.0
- *        void vld_execute_ex(zend_execute_data *execute_data TSRMLS_DC)
- *    PHP <= 5.4.x
- *        void vld_execute(zend_op_array *op_array TSRMLS_DC)
  *    This function provides a hook for execution */
-#if PHP_VERSION_ID >= 50500
 static void vld_execute_ex(zend_execute_data *execute_data TSRMLS_DC)
-#else
-static void vld_execute(zend_op_array *op_array TSRMLS_DC)
-#endif
 {
 	// nothing to do
 }
